<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About KeePassXC</source>
        <translation>À propos de KeePassXC</translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <source>Contributors</source>
        <translation>Contributeurs</translation>
    </message>
    <message>
        <source>Debug Info</source>
        <translation>Informations de débogage</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copier dans le presse-papier</translation>
    </message>
    <message>
        <source>Version %1
</source>
        <translation>Version %1
</translation>
    </message>
    <message>
        <source>Revision: %1</source>
        <translation>Révision : %1</translation>
    </message>
    <message>
        <source>Libraries:</source>
        <translation>Bibliothèques :</translation>
    </message>
    <message>
        <source>Operating system: %1
CPU architecture: %2
Kernel: %3 %4</source>
        <translation>Système d&apos;exploitation : %1
Architecture CPU : %2
Kernel : %3 %4</translation>
    </message>
    <message>
        <source>Enabled extensions:</source>
        <translation>Extensions activées :</translation>
    </message>
    <message>
        <source>Report bugs at: &lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/issues&quot; style=&quot;text-decoration: underline;&quot;&gt;https://github.com&lt;/a&gt;</source>
        <translation>Signaler les bugs sur : &lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/issues&quot; style=&quot;text-decoration: underline;&quot;&gt;https://github.com&lt;/a&gt;</translation>
    </message>
    <message>
        <source>KeePassXC is distributed under the terms of the GNU General Public License (GPL) version 2 or (at your option) version 3.</source>
        <translation>KeePassXC est distribué suivant les termes de la GNU Licence Publique Générale (GNU GPL) version 2 ou version 3 de la licence (à votre choix).</translation>
    </message>
    <message>
        <source>Project Maintainers:</source>
        <translation>Mainteneurs du projet :</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/graphs/contributors&quot;&gt;See Contributions on GitHub&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/graphs/contributors&quot;&gt;Voir Contributions sur GitHub&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Include the following information whenever you report a bug:</source>
        <translation>Inclure l&apos;information suivante lorsque vous signaler un bug :</translation>
    </message>
    <message>
        <source>Distribution: %1</source>
        <translation>Distribution : %1</translation>
    </message>
</context>
<context>
    <name>AccessControlDialog</name>
    <message>
        <source>Remember this decision</source>
        <translation>Se souvenir de ce choix</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Autoriser</translation>
    </message>
    <message>
        <source>Deny</source>
        <translation>Refuser</translation>
    </message>
    <message>
        <source>%1 has requested access to passwords for the following item(s).
Please select whether you want to allow access.</source>
        <translation>%1 a demandé l’accès aux mots de passe pour l&apos;élément suivant (ou les éléments suivants).
Veuillez sélectionner si vous souhaitez autoriser l’accès.</translation>
    </message>
    <message>
        <source>KeePassXC HTTP Confirm Access</source>
        <translation>Accès KeePassXC HTTP confirmé</translation>
    </message>
</context>
<context>
    <name>AutoType</name>
    <message>
        <source>Couldn&apos;t find an entry that matches the window title:</source>
        <translation>Impossible de trouver une entrée qui corresponde au titre de la fenêtre :</translation>
    </message>
    <message>
        <source>Auto-Type - KeePassXC</source>
        <translation>Remplissage automatique - KeePassXC</translation>
    </message>
</context>
<context>
    <name>AutoTypeAssociationsModel</name>
    <message>
        <source>Window</source>
        <translation>Fenêtre</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation>Séquence</translation>
    </message>
    <message>
        <source>Default sequence</source>
        <translation>Séquence par défaut</translation>
    </message>
</context>
<context>
    <name>AutoTypeSelectDialog</name>
    <message>
        <source>Select entry to Auto-Type:</source>
        <translation>Choisissez un champ pour Auto-Type :</translation>
    </message>
    <message>
        <source>Auto-Type - KeePassXC</source>
        <translation> Remplissage automatique - KeePassXC</translation>
    </message>
</context>
<context>
    <name>ChangeMasterKeyWidget</name>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Enter password:</source>
        <translation>Entrez un mot de passe :</translation>
    </message>
    <message>
        <source>Repeat password:</source>
        <translation>Confirmez le mot de passe :</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Naviguer</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Créer</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>Fichiers-clés</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Tous les fichiers</translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation>Créer un fichier-clé...</translation>
    </message>
    <message>
        <source>Unable to create Key File : </source>
        <translation>Impossible de créer un fichier-clé :</translation>
    </message>
    <message>
        <source>Select a key file</source>
        <translation>Choisir un fichier-clé</translation>
    </message>
    <message>
        <source>Do you really want to use an empty string as password?</source>
        <translation>Voulez-vous vraiment utiliser une chaîne vide comme mot de passe ?</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>Les mots de passe insérés sont différents.</translation>
    </message>
    <message>
        <source>Failed to set %1 as the Key file:
%2</source>
        <translation>Impossible de définir %1 comme fichier-clé :
%2</translation>
    </message>
    <message>
        <source>&amp;Key file</source>
        <translation>Fichier-clé</translation>
    </message>
    <message>
        <source>Cha&amp;llenge Response</source>
        <translation>Cha&amp;llenge-réponse</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Rafraîchir</translation>
    </message>
    <message>
        <source>Empty password</source>
        <translation>Mot de passe vide</translation>
    </message>
    <message>
        <source>Changing master key failed: no YubiKey inserted.</source>
        <translation>Échec du changement de clé maître: pas de YubiKey insérée.</translation>
    </message>
</context>
<context>
    <name>CloneDialog</name>
    <message>
        <source>Clone Options</source>
        <translation>Options de clonage</translation>
    </message>
    <message>
        <source>Replace username and password with references</source>
        <translation>Remplacer le nom d&apos;utilisateur et le mot de passe par des références</translation>
    </message>
    <message>
        <source>Copy history</source>
        <translation>Copie de l&apos;historique</translation>
    </message>
    <message>
        <source>Append &apos; - Clone&apos; to title</source>
        <translation>Ajouter &apos; - Clone&apos; au titre</translation>
    </message>
</context>
<context>
    <name>CsvImportWidget</name>
    <message>
        <source>Import CSV fields</source>
        <translation>Importer les champs CSV</translation>
    </message>
    <message>
        <source>filename</source>
        <translation>nom de fichier</translation>
    </message>
    <message>
        <source>size, rows, columns</source>
        <translation>taille, lignes, colonnes</translation>
    </message>
    <message>
        <source>Encoding</source>
        <translation>Encodage</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Text is qualified by</source>
        <translation>Le texte est encadré par</translation>
    </message>
    <message>
        <source>Fields are separated by</source>
        <translation>Les champs sont séparés par</translation>
    </message>
    <message>
        <source>Comments start with</source>
        <translation>Les commentaires commencent par</translation>
    </message>
    <message>
        <source>First record has field names</source>
        <translation>Le premier enregistrement contient les noms de champs</translation>
    </message>
    <message>
        <source>Number of headers line to discard</source>
        <translation>Nombre de lignes d&apos;en-tête à ignorer</translation>
    </message>
    <message>
        <source>Consider &apos;\&apos; an escape character</source>
        <translation>Considère &apos;\&apos; comme un échappement</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Prévisualisation</translation>
    </message>
    <message>
        <source>Column layout</source>
        <translation>Disposition des colonnes</translation>
    </message>
    <message>
        <source>Not present in CSV file</source>
        <translation>Non présent dans le fichier CSV</translation>
    </message>
    <message>
        <source>Empty fieldname </source>
        <translation>Nom de champ vide</translation>
    </message>
    <message>
        <source>column </source>
        <translation>colonne</translation>
    </message>
    <message>
        <source>Imported from CSV file</source>
        <translation>Importé du fichier CSV</translation>
    </message>
    <message>
        <source>Original data: </source>
        <translation>Données originales :</translation>
    </message>
    <message>
        <source>Error(s) detected in CSV file !</source>
        <translation>Erreur(s) détectées dans le fichier CSV!</translation>
    </message>
    <message>
        <source> more messages skipped]</source>
        <translation>plus de messages ignorés]</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>CSV import: writer has errors:
</source>
        <translation>Import CSV: erreurs d&apos;écriture:
</translation>
    </message>
</context>
<context>
    <name>CsvImportWizard</name>
    <message>
        <source>Import CSV file</source>
        <translation>Importer un fichier CSV</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Impossible de calculer la clé maître</translation>
    </message>
</context>
<context>
    <name>CsvParserModel</name>
    <message>
        <source> byte, </source>
        <translation>octet,</translation>
    </message>
    <message>
        <source> rows, </source>
        <translation>lignes,</translation>
    </message>
    <message>
        <source> columns</source>
        <translation>colonnes</translation>
    </message>
</context>
<context>
    <name>DatabaseOpenWidget</name>
    <message>
        <source>Enter master key</source>
        <translation>Entrez la clé maître</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>Fichier-clé :</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Mot de passe :</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Naviguer</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Impossible d&apos;ouvrir la base de données.</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>Impossible d&apos;ouvrir le fichier-clé</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Tous les fichiers</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>Fichiers-clés</translation>
    </message>
    <message>
        <source>Select key file</source>
        <translation>Choisissez un fichier-clé</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Rafraîchir</translation>
    </message>
    <message>
        <source>Challenge Response:</source>
        <translation>Challenge-réponse :</translation>
    </message>
</context>
<context>
    <name>DatabaseRepairWidget</name>
    <message>
        <source>Repair database</source>
        <translation>Réparer la base de données</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>Impossible d&apos;ouvrir le fichier-clé</translation>
    </message>
    <message>
        <source>Database opened fine. Nothing to do.</source>
        <translation>La base de données s&apos;est bien ouverte. Aucune action nécéssaire.</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Impossible d&apos;ouvrir la base de données.</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Réussite</translation>
    </message>
    <message>
        <source>The database has been successfully repaired
You can now save it.</source>
        <translation>La base de données a correctement été réparée.
Vous pouvez maintenant la sauvegarder.</translation>
    </message>
    <message>
        <source>Unable to repair the database.</source>
        <translation>Impossible de réparer la base de données.</translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsWidget</name>
    <message>
        <source>Database name:</source>
        <translation>Nom de la base de données :</translation>
    </message>
    <message>
        <source>Database description:</source>
        <translation>Description de la base de données :</translation>
    </message>
    <message>
        <source>Transform rounds:</source>
        <translation>Passes de transformation :</translation>
    </message>
    <message>
        <source>Default username:</source>
        <translation>Nom d&apos;utilisateur par défaut :</translation>
    </message>
    <message>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <source>Benchmark</source>
        <translation>Base de référence</translation>
    </message>
    <message>
        <source>Max. history items:</source>
        <translation>Nombre max. d&apos;éléments dans l&apos;historique :</translation>
    </message>
    <message>
        <source>Max. history size:</source>
        <translation>Taille max. de l&apos;historique :</translation>
    </message>
    <message>
        <source>Use recycle bin</source>
        <translation>Utiliser la corbeille</translation>
    </message>
    <message>
        <source>AES:  256 Bit   (default)</source>
        <translation>AES : 256 Bits (par défaut)</translation>
    </message>
    <message>
        <source>Twofish:  256 Bit</source>
        <translation>Twofish : 256 bits</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algorithme :</translation>
    </message>
</context>
<context>
    <name>DatabaseTabWidget</name>
    <message>
        <source>Root</source>
        <translation>Racine</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>Base de données Keepass 2</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Tous les fichiers</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>Ouvrir la base de données</translation>
    </message>
    <message>
        <source>File not found!</source>
        <translation>Fichier introuvable !</translation>
    </message>
    <message>
        <source>Open KeePass 1 database</source>
        <translation>Ouvrir une base de données KeePass 1</translation>
    </message>
    <message>
        <source>KeePass 1 database</source>
        <translation>Base de données Keepass 1</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Tous les fichiers (*)</translation>
    </message>
    <message>
        <source>Close?</source>
        <translation>Fermer ?</translation>
    </message>
    <message>
        <source>Save changes?</source>
        <translation>Enregistrer les modifications ?</translation>
    </message>
    <message>
        <source>&quot;%1&quot; was modified.
Save changes?</source>
        <translation>&quot;%1&quot; a été modifié.
Enregistrer les modifications ?</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>Une erreur s&apos;est produite lors de l&apos;écriture de la base de données.</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>Enregistrer comme nouvelle base de données</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>Nouvelle base de données</translation>
    </message>
    <message>
        <source>locked</source>
        <translation>verrouillée</translation>
    </message>
    <message>
        <source>Lock database</source>
        <translation>Verrouiller la base de données</translation>
    </message>
    <message>
        <source>Can't lock the database as you are currently editing it.
Please press cancel to finish your changes or discard them.</source>
        <translation>Impossible de verrouiller la base de données lors de modifications.
Cliquez sur Annuler pour finir vos modifications ou abandonnez-les.</translation>
    </message>
    <message>
        <source>This database has never been saved.
You can save the database or stop locking it.</source>
        <translation>Cette base de données n&apos;a pas encore été sauvegardée.
Vous devez la sauvegarder ou annuler son verrouillage.</translation>
    </message>
    <message>
        <source>This database has been modified.
Do you want to save the database before locking it?
Otherwise your changes are lost.</source>
        <translation>La base de données a été modifiée.
Voulez-vous l&apos;enregistrer avant de la verrouiller ?
Autrement, vos modifications seront perdues.</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is in edit mode.
Discard changes and close anyway?</source>
        <translation>&quot;%1&quot; est en mode édition.
Ignorer les changements et fermer ?</translation>
    </message>
    <message>
        <source>Export database to CSV file</source>
        <translation>Exporter la base de données au format CSV</translation>
    </message>
    <message>
        <source>CSV file</source>
        <translation>Fichier CSV</translation>
    </message>
    <message>
        <source>Writing the CSV file failed.</source>
        <translation>Échec de l&apos;écriture du fichier CSV.</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Impossible d&apos;ouvrir la base de données.</translation>
    </message>
    <message>
        <source>Merge database</source>
        <translation>Fusionner les bases de données</translation>
    </message>
    <message>
        <source>The database you are trying to save as is locked by another instance of KeePassXC.
Do you want to save it anyway?</source>
        <translation>La base de données que vous essayez d&apos;enregistrer est verrouillée par une autre instance de KeePassXC.
Voulez vous l&apos;enregistrer quand même ?</translation>
    </message>
    <message>
        <source>Passwords</source>
        <translation>Mots de passe</translation>
    </message>
    <message>
        <source>Database already opened</source>
        <translation>La base de données est déjà ouverte</translation>
    </message>
    <message>
        <source>The database you are trying to open is locked by another instance of KeePassXC.

Do you want to open it anyway?</source>
        <translation>La base de données que vous essayez d&apos;ouvrir est verrouillée par une autre instance de KeePassXC.

Voulez vous l&apos;ouvrir quand même ?</translation>
    </message>
    <message>
        <source>Open read-only</source>
        <translation>Ouvrir en lecture seule</translation>
    </message>
    <message>
        <source>File opened in read only mode.</source>
        <translation>Fichier ouvert en lecture seule.</translation>
    </message>
    <message>
        <source>Open CSV file</source>
        <translation>Ouvrir le fichier CSV</translation>
    </message>
</context>
<context>
    <name>DatabaseWidget</name>
    <message>
        <source>Change master key</source>
        <translation>Changer la clé maître</translation>
    </message>
    <message>
        <source>Delete entry?</source>
        <translation>Supprimer l&apos;entrée ?</translation>
    </message>
    <message>
        <source>Do you really want to delete the entry &quot;%1&quot; for good?</source>
        <translation>Voulez-vous supprimer l&apos;entrée &quot;%1&quot; définitivement ?</translation>
    </message>
    <message>
        <source>Delete entries?</source>
        <translation>Supprimer les entrées ?</translation>
    </message>
    <message>
        <source>Do you really want to delete %1 entries for good?</source>
        <translation>Voulez-vous supprimer &quot;%1&quot; entrées définitivement ?</translation>
    </message>
    <message>
        <source>Move entries to recycle bin?</source>
        <translation>Déplacer les entrées vers la corbeille ?</translation>
    </message>
    <message numerus="yes">
        <source>Do you really want to move %n entry(s) to the recycle bin?</source>
        <translation><numerusform>Voulez-vous déplacer %n entrée(s) vers la corbeille ?</numerusform><numerusform>Voulez-vous déplacer %n entrée(s) vers la corbeille ?</numerusform></translation>
    </message>
    <message>
        <source>Delete group?</source>
        <translation>Supprimer le groupe ?</translation>
    </message>
    <message>
        <source>Do you really want to delete the group &quot;%1&quot; for good?</source>
        <translation>Voulez-vous supprimer le groupe &quot;%1&quot; définitivement ?</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Impossible de calculer la clé maître</translation>
    </message>
    <message>
        <source>Move entry to recycle bin?</source>
        <translation>Déplacer l&apos;entrée dans la corbeille ?</translation>
    </message>
    <message>
        <source>Do you really want to move entry &quot;%1&quot; to the recycle bin?</source>
        <translation>Êtes-vous sûr de vouloir déplacer l&apos;entrée &quot;%1&quot; dans la corbeille ?</translation>
    </message>
    <message>
        <source>Searching...</source>
        <translation>Recherche...</translation>
    </message>
    <message>
        <source>No current database.</source>
        <translation>Pas de base de données.</translation>
    </message>
    <message>
        <source>No source database, nothing to do.</source>
        <translation>Aucune base de données source, il n&apos;y a rien à faire.</translation>
    </message>
    <message>
        <source>Search Results (%1)</source>
        <translation>Résultats de la recherche (%1)</translation>
    </message>
    <message>
        <source>No Results</source>
        <translation>Pas de résultats</translation>
    </message>
    <message>
        <source>Execute command?</source>
        <translation>Exécuter la commande ?</translation>
    </message>
    <message>
        <source>Do you really want to execute the following command?&lt;br&gt;&lt;br&gt;%1&lt;br&gt;</source>
        <translation>Voulez-vous vraiment exécuter la commande suivante ?&lt;br&gt;&lt;br&gt;%1&lt;br&gt;</translation>
    </message>
    <message>
        <source>Remember my choice</source>
        <translation>Se souvenir de mon choix</translation>
    </message>
    <message>
        <source>Autoreload Request</source>
        <translation>Demande de rafraîchissement automatique</translation>
    </message>
    <message>
        <source>The database file has changed. Do you want to load the changes?</source>
        <translation>Le fichier de la base de données à été modifié. Voulez-vous charger les changements ?</translation>
    </message>
    <message>
        <source>Merge Request</source>
        <translation>Demande de fusion</translation>
    </message>
    <message>
        <source>The database file has changed and you have unsaved changes.Do you want to merge your changes?</source>
        <translation>Le fichier de la base de données à changé et vous avez des modification non-enregistrés. Voulez-vous fusionner vos modifications?</translation>
    </message>
    <message>
        <source>Could not open the new database file while attempting to autoreload this database.</source>
        <translation>La nouvelle base de données ne peut être ouverte pendant qu&apos;un rafraîchissement automatique de l&apos;actuelle est en cours.</translation>
    </message>
    <message>
        <source>Empty recycle bin?</source>
        <translation>Vider la corbeille?</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete everything from your recycle bin?</source>
        <translation>Êtes-vous certain de vouloir vider définitivement votre corbeille?</translation>
    </message>
</context>
<context>
    <name>EditEntryWidget</name>
    <message>
        <source>Entry</source>
        <translation>Entrée</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avancé</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Icône</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>Remplissage automatique</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historique</translation>
    </message>
    <message>
        <source>Entry history</source>
        <translation>Historique de l&apos;entrée</translation>
    </message>
    <message>
        <source>Add entry</source>
        <translation>Ajouter une entrée</translation>
    </message>
    <message>
        <source>Edit entry</source>
        <translation>Modifier l&apos;entrée</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>Les mots de passe ne sont pas identiques.</translation>
    </message>
    <message>
        <source>New attribute</source>
        <translation>Nouvel attribut</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Choisissez un fichier</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation>Impossible d&apos;ouvrir le fichier</translation>
    </message>
    <message>
        <source>Save attachment</source>
        <translation>Enregistrer le fichier attaché</translation>
    </message>
    <message>
        <source>Unable to save the attachment:
</source>
        <translation>Impossible d&apos;enregistrer le fichier attaché :
</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Demain</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n semaine(s)</numerusform><numerusform>%n semaine(s)</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s)</source>
        <translation><numerusform>%n mois</numerusform><numerusform>%n mois</numerusform></translation>
    </message>
    <message>
        <source>1 year</source>
        <translation>1 an</translation>
    </message>
    <message>
        <source>Confirm Remove</source>
        <translation>Confirmez la suppression</translation>
    </message>
    <message>
        <source>Are you sure you want to remove this attribute?</source>
        <translation>Êtes-vous sûr de vouloir supprimer cet attribut?</translation>
    </message>
    <message>
        <source>[PROTECTED] Press reveal to view or edit</source>
        <translation>[PROTÉGÉ] Appuyez pour révéler ou éditer</translation>
    </message>
    <message>
        <source>Are you sure you want to remove this attachment?</source>
        <translation>Êtes-vous sûr de vouloir supprimer cette pièce jointe?</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAdvanced</name>
    <message>
        <source>Additional attributes</source>
        <translation>Attributs supplémentaires</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Attachments</source>
        <translation>Affichage</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enregistrer le fichier</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation>Éditer le nom</translation>
    </message>
    <message>
        <source>Protect</source>
        <translation>Protéger</translation>
    </message>
    <message>
        <source>Reveal</source>
        <translation>Révéler</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAutoType</name>
    <message>
        <source>Enable Auto-Type for this entry</source>
        <translation>Activer le remplissage automatique pour cette entrée</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Window title:</source>
        <translation>Titre de la fenêtre :</translation>
    </message>
    <message>
        <source>Inherit default Auto-Type sequence from the &amp;group</source>
        <translation>Utiliser la séquence de remplissage automatique par défaut du groupe</translation>
    </message>
    <message>
        <source>&amp;Use custom Auto-Type sequence:</source>
        <translation>Utiliser une séquence de remplissage automatique personnalisée :</translation>
    </message>
    <message>
        <source>Use default se&amp;quence</source>
        <translation>Utiliser la séquence par défaut</translation>
    </message>
    <message>
        <source>Set custo&amp;m sequence:</source>
        <translation>Définir une séquence personnalisée :</translation>
    </message>
    <message>
        <source>Window Associations</source>
        <translation>Associations de fenêtre</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetHistory</name>
    <message>
        <source>Show</source>
        <translation>Afficher</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Rétablir</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Delete all</source>
        <translation>Supprimer tout</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetMain</name>
    <message>
        <source>Title:</source>
        <translation>Titre :</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nom d&apos;utilisateur :</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Mot de passe :</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>Confirmation :</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL :</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Expiration</translation>
    </message>
    <message>
        <source>Presets</source>
        <translation>Valeurs par défaut</translation>
    </message>
    <message>
        <source>Notes:</source>
        <translation>Notes :</translation>
    </message>
</context>
<context>
    <name>EditGroupWidget</name>
    <message>
        <source>Group</source>
        <translation>Groupe</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Icône</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <source>Add group</source>
        <translation>Ajouter un groupe</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>Modifier le groupe</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Activer</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Désactiver</translation>
    </message>
    <message>
        <source>Inherit from parent group (%1)</source>
        <translation>Hériter du groupe parent (%1)</translation>
    </message>
</context>
<context>
    <name>EditGroupWidgetMain</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Notes</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Expiration</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Chercher</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>Saisie-Automatique</translation>
    </message>
    <message>
        <source>&amp;Use default Auto-Type sequence of parent group</source>
        <translation>&amp;Utiliser la séquence de Saisie-Automatique du groupe parent</translation>
    </message>
    <message>
        <source>Set default Auto-Type se&amp;quence</source>
        <translation>Définir la sé&amp;quence par défaut de la Saisie-Automatique</translation>
    </message>
</context>
<context>
    <name>EditWidgetIcons</name>
    <message>
        <source>Add custom icon</source>
        <translation>Ajouter une icône personnalisée</translation>
    </message>
    <message>
        <source>Delete custom icon</source>
        <translation>Supprimer une icône personnalisée</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Tous les dossiers</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>Choisir une image</translation>
    </message>
    <message>
        <source>Download favicon</source>
        <translation>Télécharger la favicône</translation>
    </message>
    <message>
        <source>Unable to fetch favicon.</source>
        <translation>Impossible de récupérer la favicône</translation>
    </message>
    <message>
        <source>Can&apos;t read icon</source>
        <translation>Impossible de lire l&apos;icône</translation>
    </message>
    <message>
        <source>&amp;Use default icon</source>
        <translation>Utiliser l&apos;icône par défaut</translation>
    </message>
    <message>
        <source>Use custo&amp;m icon</source>
        <translation>Utiliser une icône personnalisée</translation>
    </message>
    <message>
        <source>Confirm Delete</source>
        <translation>Confirmer la suppression</translation>
    </message>
    <message>
        <source>This icon is used by %1 entries, and will be replaced by the default icon. Are you sure you want to delete it?</source>
        <translation>Cette icône est utilisée par %1 entrée et sera remplacée par l&apos;icône par défaut. Êtes-vous sûr de vouloir l&apos;effacer?</translation>
    </message>
    <message>
        <source>Hint: You can enable Google as a fallback under Tools&gt;Settings&gt;Security</source>
        <translation>Astuce : Vous pouvez activer Google en tant que repli sous Outils&gt;Paramètres&gt;Sécurité</translation>
    </message>
    <message>
        <source>Custom icon already exists</source>
        <translation>L&apos;icône personnalisée existe déjà</translation>
    </message>
</context>
<context>
    <name>EditWidgetProperties</name>
    <message>
        <source>Created:</source>
        <translation>Créé le :</translation>
    </message>
    <message>
        <source>Modified:</source>
        <translation>Modifié le :</translation>
    </message>
    <message>
        <source>Accessed:</source>
        <translation>Accédé le :</translation>
    </message>
    <message>
        <source>Uuid:</source>
        <translation>Uuid :</translation>
    </message>
</context>
<context>
    <name>Entry</name>
    <message>
        <source> - Clone</source>
        <translation> - Cloner</translation>
    </message>
</context>
<context>
    <name>EntryAttributesModel</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
</context>
<context>
    <name>EntryHistoryModel</name>
    <message>
        <source>Last modified</source>
        <translation>Dernière modification</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
</context>
<context>
    <name>EntryModel</name>
    <message>
        <source>Group</source>
        <translation>Groupe</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Ref: </source>
        <comment>Reference abbreviation</comment>
        <translation>Réf : </translation>
    </message>
</context>
<context>
    <name>Group</name>
    <message>
        <source>Recycle Bin</source>
        <translation>Corbeille</translation>
    </message>
</context>
<context>
    <name>HttpPasswordGeneratorWidget</name>
    <message>
        <source>Length:</source>
        <translation>Longueur:</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>Types de caractères:</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>Lettres majuscules</translation>
    </message>
    <message>
        <source>A-Z</source>
        <translation>A-Z</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>Lettres minuscules</translation>
    </message>
    <message>
        <source>a-z</source>
        <translation>a-z</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>Chiffres</translation>
    </message>
    <message>
        <source>0-9</source>
        <translation>0-9</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>Caractères spéciaux</translation>
    </message>
    <message>
        <source>/*_&amp; ...</source>
        <translation>/*_&amp; ...</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>Exclure les caractères qui se ressemblent</translation>
    </message>
    <message>
        <source>Ensure that the password contains characters from every group</source>
        <translation>S&apos;assurer que le mot de passe contienne des caractères de chaque groupe</translation>
    </message>
</context>
<context>
    <name>KMessageWidget</name>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <source>Close message</source>
        <translation>Fermer le message</translation>
    </message>
</context>
<context>
    <name>KeePass1OpenWidget</name>
    <message>
        <source>Import KeePass1 database</source>
        <translation>Importer une base de données au format KeePass1</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Impossible d&apos;ouvrir la base de données.</translation>
    </message>
</context>
<context>
    <name>KeePass1Reader</name>
    <message>
        <source>Unable to read keyfile.</source>
        <translation>Impossible de lire le fichier-clé.</translation>
    </message>
    <message>
        <source>Not a KeePass database.</source>
        <translation>Ce n&apos;est pas une base de données KeePass.</translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation>Algorithme de chiffrement non supporté.</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>Version de base de données KeePass non supportée.</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>Racine</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Impossible de calculer la clé maître</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>Clé incorrecte ou la base de données est corrompue.</translation>
    </message>
</context>
<context>
    <name>KeePass2Reader</name>
    <message>
        <source>Not a KeePass database.</source>
        <translation>Ce n&apos;est pas une base de données KeePass.</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>Version de base de données KeePass non supportée.</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>Mauvaise clé ou fichier de base de données corrompu.</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Impossible de calculer la clé maître</translation>
    </message>
    <message>
        <source>Unable to issue challenge-response.</source>
        <translation>Impossible de lancer une challenge-réponse.</translation>
    </message>
    <message>
        <source>The selected file is an old KeePass 1 database (.kdb).

You can import it by clicking on Database &gt; 'Import KeePass 1 database...'.
This is a one-way migration. You won&apos;t be able to open the imported database with the old KeePassX 0.4 version.</source>
        <translation>Le fichier sélectionné est une ancienne base de données KeePass 1 (.kdb).

Vous pouvez l&apos;importer en cliquant sur Base de données&gt;&apos;Importer une base de données KeePass 1 ...&apos;
Il s&apos;agit d&apos;une migration à sens unique. Vous ne pourrez pas ouvrir la base de données importée avec l&apos;ancienne version de KeePassX 0.4.</translation>
    </message>
</context>
<context>
    <name>KeePass2Writer</name>
    <message>
        <source>Unable to issue challenge-response.</source>
        <translation>Impossible de lancer une challenge-réponse.</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Impossible de calculer la clé maître</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Fatal error while testing the cryptographic functions.</source>
        <translation>Erreur fatale lors des tests des fonctions cryptographiques.</translation>
    </message>
    <message>
        <source>KeePassXC - Error</source>
        <translation>KeePassXC - Erreur</translation>
    </message>
    <message>
        <source>The lock file could not be created. Single-instance mode disabled.</source>
        <translation>Le fichier verrou ne peut pas être créé. Le mode instance-unique est désactivé.</translation>
    </message>
    <message>
        <source>Another instance of KeePassXC is already running.</source>
        <translation>Une autre instance de KeePassXC est déjà en cours d&apos;exécution.</translation>
    </message>
    <message>
        <source>Existing single-instance lock file is invalid. Launching new instance.</source>
        <translation>Le fichier de verrouillage de l’instance unique existant n’est pas valide. Lancement d&apos;une nouvelle instance.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Open database</source>
        <translation>Ouvrir une base de données</translation>
    </message>
    <message>
        <source>Database settings</source>
        <translation>Paramètres de la base de données</translation>
    </message>
    <message>
        <source>Copy username to clipboard</source>
        <translation>Copier le nom d&apos;utilisateur dans le presse-papier</translation>
    </message>
    <message>
        <source>Copy password to clipboard</source>
        <translation>Copier le mot de passe dans le presse-papier</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Show toolbar</source>
        <translation>Afficher la barre d&apos;outils</translation>
    </message>
    <message>
        <source>read-only</source>
        <translation>Lecture seulement</translation>
    </message>
    <message>
        <source>Toggle window</source>
        <translation>Basculer de fenêtre</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>Base de données KeePass 2</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Tous les fichiers</translation>
    </message>
    <message>
        <source>Save repaired database</source>
        <translation>Sauvegarder la base de données réparée</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>Une erreur s&apos;est produite lors de l&apos;écriture de la base de données.</translation>
    </message>
    <message>
        <source>&amp;Recent databases</source>
        <translation>Bases de données récentes</translation>
    </message>
    <message>
        <source>E&amp;ntries</source>
        <translation>Entrées</translation>
    </message>
    <message>
        <source>Copy att&amp;ribute to clipboard</source>
        <translation>Copier l&apos;attribut dans le presse-papier</translation>
    </message>
    <message>
        <source>&amp;Groups</source>
        <translation>Groupes</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>Affichage</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;À propos</translation>
    </message>
    <message>
        <source>&amp;Save database</source>
        <translation>Enregistrer la base de données</translation>
    </message>
    <message>
        <source>&amp;Close database</source>
        <translation>Fermer la base de données</translation>
    </message>
    <message>
        <source>&amp;New database</source>
        <translation>&amp;Nouvelle base de données</translation>
    </message>
    <message>
        <source>Merge from KeePassX database</source>
        <translation>Fusionner depuis la base de données KeePassX</translation>
    </message>
    <message>
        <source>&amp;Add new entry</source>
        <translation>Ajouter une nouvelle entrée</translation>
    </message>
    <message>
        <source>&amp;View/Edit entry</source>
        <translation>Voir/Editer l&apos;entrée</translation>
    </message>
    <message>
        <source>&amp;Delete entry</source>
        <translation>Supprimer l&apos;entrée</translation>
    </message>
    <message>
        <source>&amp;Add new group</source>
        <translation>&amp;Ajouter un nouveau groupe</translation>
    </message>
    <message>
        <source>&amp;Edit group</source>
        <translation>&amp;Modifier le groupe</translation>
    </message>
    <message>
        <source>&amp;Delete group</source>
        <translation>&amp;Supprimer le groupe</translation>
    </message>
    <message>
        <source>&amp;Database settings</source>
        <translation>Paramètre de la base de &amp;données</translation>
    </message>
    <message>
        <source>&amp;Clone entry</source>
        <translation>Cloner l&apos;entrée</translation>
    </message>
    <message>
        <source>Timed one-time password</source>
        <translation>Mot de passe à usage unique</translation>
    </message>
    <message>
        <source>Copy &amp;TOTP</source>
        <translation>Copie &amp;TOTP</translation>
    </message>
    <message>
        <source>Show TOTP</source>
        <translation>Afficher TOTP</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>Trouver</translation>
    </message>
    <message>
        <source>Copy &amp;username</source>
        <translation>Copier le nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Cop&amp;y password</source>
        <translation>Copier le mot de passe</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>&amp;Perform Auto-Type</source>
        <translation>Exécuter la saisie semi-automatique</translation>
    </message>
    <message>
        <source>&amp;Open URL</source>
        <translation>&amp;Ouvrir l&apos;URL</translation>
    </message>
    <message>
        <source>&amp;Lock databases</source>
        <translation>Verrouiller les bases de données</translation>
    </message>
    <message>
        <source>&amp;Title</source>
        <translation>&amp;Titre</translation>
    </message>
    <message>
        <source>&amp;URL</source>
        <translation>&amp;URL</translation>
    </message>
    <message>
        <source>&amp;Notes</source>
        <translation>&amp;Notes</translation>
    </message>
    <message>
        <source>Password Generator</source>
        <translation>Générateur de mot de passe</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Effacer l&apos;historique</translation>
    </message>
    <message>
        <source>&amp;Database</source>
        <translation>&amp;Base de données</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importer</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Outils</translation>
    </message>
    <message>
        <source>Empty recycle bin</source>
        <translation>Vider la corbeille</translation>
    </message>
    <message>
        <source>Access error for config file %1</source>
        <translation>Erreur d&apos;accès au fichier de configuration %1</translation>
    </message>
    <message>
        <source>Quit KeePassXC</source>
        <translation>Quitter KeePass XC</translation>
    </message>
    <message>
        <source>Please touch the button on your YubiKey!</source>
        <translation>Veuillez presser le bouton de votre YubiKey!</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>&amp;Open database...</source>
        <translation>&amp;Ouvrir la base de donnée...</translation>
    </message>
    <message>
        <source>Sa&amp;ve database as...</source>
        <translation>Sau&amp;ver la base de données sous...</translation>
    </message>
    <message>
        <source>Change &amp;master key...</source>
        <translation>Changer la clé &amp;maître...</translation>
    </message>
    <message>
        <source>&amp;Export to CSV file...</source>
        <translation>&amp;Exporter dans un fichier CSV...</translation>
    </message>
    <message>
        <source>Import KeePass 1 database...</source>
        <translation>Importer une base de données KeePass 1...</translation>
    </message>
    <message>
        <source>Import CSV file...</source>
        <translation>Importer un fichier CSV...</translation>
    </message>
    <message>
        <source>Re&amp;pair database...</source>
        <translation>Ré&amp;parer la base de données...</translation>
    </message>
    <message>
        <source>Set up TOTP...</source>
        <translation>Configurer TOTP...</translation>
    </message>
</context>
<context>
    <name>OptionDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Sh&amp;ow a notification when credentials are requested</source>
        <translation>Montrer une notification quand les références sont demandées</translation>
    </message>
    <message>
        <source>Sort matching entries by &amp;username</source>
        <translation>Trier les entrées correspondantes par nom d&apos;&amp;utilisateur</translation>
    </message>
    <message>
        <source>Re&amp;move all stored permissions from entries in active database</source>
        <translation>Supprimer toutes les permissions enregistrées des entrées de la base de données active</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avancé</translation>
    </message>
    <message>
        <source>Always allow &amp;access to entries</source>
        <translation>Toujours autoriser l&apos;&amp;accès aux entrées</translation>
    </message>
    <message>
        <source>Always allow &amp;updating entries</source>
        <translation>Toujours autoriser la mise à jour des entrées</translation>
    </message>
    <message>
        <source>Searc&amp;h in all opened databases for matching entries</source>
        <translation>Cherc&amp;her dans toutes les bases de données ouvertes les entrées correspondantes</translation>
    </message>
    <message>
        <source>HTTP Port:</source>
        <translation>Port HTTP :</translation>
    </message>
    <message>
        <source>Default port: 19455</source>
        <translation>Port par défaut : 19455</translation>
    </message>
    <message>
        <source>Re&amp;quest to unlock the database if it is locked</source>
        <translation>Demander de déverrouiller la base de données lorsque celle-ci est verrouillée</translation>
    </message>
    <message>
        <source>Sort &amp;matching entries by title</source>
        <translation>Trier les entrées correspondantes par titre</translation>
    </message>
    <message>
        <source>KeePassXC will listen to this port on 127.0.0.1</source>
        <translation>KeepassXC va écouter ce port sur 127.0.0.1</translation>
    </message>
    <message>
        <source>Cannot bind to privileged ports</source>
        <translation>Liaison impossible avec les ports privilégiés</translation>
    </message>
    <message>
        <source>Cannot bind to privileged ports below 1024!
Using default port 19455.</source>
        <translation>Liaison impossible avec les ports privilégiés, ceux avant 1024 !
Restauration du port 19455 par défaut.</translation>
    </message>
    <message>
        <source>R&amp;emove all shared encryption keys from active database</source>
        <translation>Supprimer toutes les clés de chiffrement partagées de la base de données active</translation>
    </message>
    <message>
        <source>&amp;Return advanced string fields which start with &quot;KPH: &quot;</source>
        <translation>&amp; Retourne les champs avancés de type chaîne qui commencent par &quot;KPH :&quot;</translation>
    </message>
    <message>
        <source>Automatically creating or updating string fields is not supported.</source>
        <translation>La création ou la mise a jour automatique ne sont pas pris en charge pour les champs de chaines de caractères !</translation>
    </message>
    <message>
        <source>This is required for accessing your databases from ChromeIPass or PassIFox</source>
        <translation>Ceci est requis pour accéder à vos bases de données à partir de ChromeIPass ou PassIFox</translation>
    </message>
    <message>
        <source>Enable KeePassHTTP server</source>
        <translation>Activer le serveur KeePassHTTP</translation>
    </message>
    <message>
        <source>Only returns the best matches for a specific URL instead of all entries for the whole domain.</source>
        <translation>Renvoie seulement les meilleures correspondances pour une URL spécifique au lieu des entrées pour tout le domaine.</translation>
    </message>
    <message>
        <source>&amp;Return only best matching entries</source>
        <translation>&amp;Retourner seulement les meilleurs entrées</translation>
    </message>
    <message>
        <source>Only entries with the same scheme (http://, https://, ftp://, ...) are returned.</source>
        <translation>Seules les entrées avec le même schéma (http://, https://, ftp://, ...) sont retournées.</translation>
    </message>
    <message>
        <source>&amp;Match URL schemes</source>
        <translation>&amp;Schémas de correspondance URL</translation>
    </message>
    <message>
        <source>Password Generator</source>
        <translation>Générateur de mot de passe</translation>
    </message>
    <message>
        <source>Only the selected database has to be connected with a client.</source>
        <translation>Seule la base de données sélectionnée doit être connectée avec un client.</translation>
    </message>
    <message>
        <source>The following options can be dangerous!
Change them only if you know what you are doing.</source>
        <translation>Les options suivantes pourraient être dangereuses!
Ne les changez que si vous savez ce que vous faites.</translation>
    </message>
</context>
<context>
    <name>PasswordGeneratorWidget</name>
    <message>
        <source>Password:</source>
        <translation>Mot de passe :</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>Types de caractères</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>Lettres majuscules</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>Lettres minuscules</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>Nombres</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>Caractères spéciaux</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>Exclure les caractères se ressemblant</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Accepter</translation>
    </message>
    <message>
        <source>%p%</source>
        <translation>%p%</translation>
    </message>
    <message>
        <source>strength</source>
        <translation>force</translation>
    </message>
    <message>
        <source>entropy</source>
        <translation>entropie</translation>
    </message>
    <message>
        <source>&amp;Length:</source>
        <translation>&amp;Longueur :</translation>
    </message>
    <message>
        <source>Pick characters from every group</source>
        <translation>Inclure des caractères de chaque groupe</translation>
    </message>
    <message>
        <source>Generate</source>
        <translation>Générer</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <source>Entropy: %1 bit</source>
        <translation>Entropie : %1 bit</translation>
    </message>
    <message>
        <source>Password Quality: %1</source>
        <translation>Qualité du mot de passe : %1</translation>
    </message>
    <message>
        <source>Poor</source>
        <translation>Pauvre</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Faible</translation>
    </message>
    <message>
        <source>Good</source>
        <translation>Bon</translation>
    </message>
    <message>
        <source>Excellent</source>
        <translation>Excellent</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Extended ASCII</source>
        <translation>ASCII étendu</translation>
    </message>
    <message>
        <source>Passphrase</source>
        <translation>Phrase secrète</translation>
    </message>
    <message>
        <source>Wordlist:</source>
        <translation>Liste de mots :</translation>
    </message>
    <message>
        <source>Word Count:</source>
        <translation>Nombre de mots :</translation>
    </message>
    <message>
        <source>Word Separator:</source>
        <translation>Séparateur de mot :</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copie</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>NULL device</source>
        <translation>Périphérique NULL</translation>
    </message>
    <message>
        <source>error reading from device</source>
        <translation>Erreur de lecture sur le périphérique</translation>
    </message>
    <message>
        <source>file empty !
</source>
        <translation>Fichier vide!
</translation>
    </message>
    <message>
        <source>malformed string</source>
        <translation>chaîne malformée</translation>
    </message>
    <message>
        <source>missing closing quote</source>
        <translation>fermeture de citation manquante</translation>
    </message>
    <message>
        <source>INTERNAL - unget lower bound exceeded</source>
        <translation>INTERNE - dépassement de la limite inférieure</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Groupe</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Notes</translation>
    </message>
    <message>
        <source>Browser Integration</source>
        <translation>Intégration Navigateur</translation>
    </message>
    <message>
        <source>YubiKey[%1] Challenge Response - Slot %2 - %3</source>
        <translation>YubiKey[%1] Challenge-réponse - Slot %2 - %3</translation>
    </message>
    <message>
        <source>Press</source>
        <translation>Pressez</translation>
    </message>
    <message>
        <source>Passive</source>
        <translation>Passif</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor</name>
    <message>
        <source>Internal zlib error when compressing: </source>
        <translation>Erreur interne zlib lors de la compression :</translation>
    </message>
    <message>
        <source>Error writing to underlying device: </source>
        <translation>Erreur d&apos;écriture sur le périphérique concerné :</translation>
    </message>
    <message>
        <source>Error opening underlying device: </source>
        <translation>Erreur d&apos;ouverture du périphérique concerné :</translation>
    </message>
    <message>
        <source>Error reading data from underlying device: </source>
        <translation>Erreur de lecture sur le périphérique concerné :</translation>
    </message>
    <message>
        <source>Internal zlib error when decompressing: </source>
        <translation>Erreur interne zlib lors de la décompression :</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor::open</name>
    <message>
        <source>The gzip format not supported in this version of zlib.</source>
        <translation>Le format gzip n&apos;est pas supporté dans cette version de zlib.</translation>
    </message>
    <message>
        <source>Internal zlib error: </source>
        <translation>Erreur interne zlib :</translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>Case Sensitive</source>
        <translation>Sensible à la casse</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Chercher</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Search...</source>
        <translation>Recherche...</translation>
    </message>
    <message>
        <source>Limit search to selected group</source>
        <translation>Limite la recherche au groupe sélectionné</translation>
    </message>
</context>
<context>
    <name>Service</name>
    <message>
        <source>A shared encryption-key with the name &quot;%1&quot; already exists.
Do you want to overwrite it?</source>
        <translation>Une clé de chiffrement partagée avec le nom &quot;%1&quot; existe déjà.
Voulez-vous l&apos;écraser ?</translation>
    </message>
    <message>
        <source>Do you want to update the information in %1 - %2?</source>
        <translation>Voulez-vous mettre à jour l&apos;information dans %1 - %2 ?</translation>
    </message>
    <message>
        <source>The active database is locked!
Please unlock the selected database or choose another one which is unlocked.</source>
        <translation>La base de données actuelle est verrouillée !
Veuillez déverrouiller la base de données sélectionnée ou en choisir une qui est déverrouillée. </translation>
    </message>
    <message>
        <source>Successfully removed %1 encryption-%2 from KeePassX/Http Settings.</source>
        <translation>%1 %2 de chiffrement ont été retirés avec succès des paramètres de KeePassX/Http.</translation>
    </message>
    <message>
        <source>No shared encryption-keys found in KeePassHttp Settings.</source>
        <translation>Aucune clé de chiffrement partagée trouvée dans les paramètres de KeePassHttp.</translation>
    </message>
    <message>
        <source>The active database does not contain an entry of KeePassHttp Settings.</source>
        <translation>La base de données actuelle ne contient pas d&apos;entrée de paramètres KeePassHttp.</translation>
    </message>
    <message>
        <source>Removing stored permissions...</source>
        <translation>Effacement des permissions enregistrées...</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Successfully removed permissions from %1 %2.</source>
        <translation>Les permissions de %1 %2 ont été retirées avec succès.</translation>
    </message>
    <message>
        <source>The active database does not contain an entry with permissions.</source>
        <translation>La base de données actuelle ne contient pas d&apos;entrée avec des permissions.</translation>
    </message>
    <message>
        <source>KeePassXC: New key association request</source>
        <translation>KeePassXC : nouvelle demande d&apos;association</translation>
    </message>
    <message>
        <source>You have received an association request for the above key.
If you would like to allow it access to your KeePassXC database
give it a unique name to identify and accept it.</source>
        <translation>Vous avez reçu une demande d&apos;association pour la clé ci-dessus.
Si vous voulez autoriser cette clé à accéder à votre base de données KeePassXC,
attribuez lui un nom unique pour l&apos;identifier et acceptez la.</translation>
    </message>
    <message>
        <source>KeePassXC: Overwrite existing key?</source>
        <translation>KeePassXC : Écraser la clé existante ?</translation>
    </message>
    <message>
        <source>KeePassXC: Update Entry</source>
        <translation>KeePassXC : Mettre à jour l&apos;entrée</translation>
    </message>
    <message>
        <source>KeePassXC: Database locked!</source>
        <translation>KeePassXC : Base de données verrouillée !</translation>
    </message>
    <message>
        <source>KeePassXC: Removed keys from database</source>
        <translation>KeePassXC : Les clés ont été effacées de la base de donnée</translation>
    </message>
    <message>
        <source>KeePassXC: No keys found</source>
        <translation>KeePassXC : Aucune clé trouvée</translation>
    </message>
    <message>
        <source>KeePassXC: Settings not available!</source>
        <translation>KeePassXC: Paramètre indisponible !</translation>
    </message>
    <message>
        <source>KeePassXC: Removed permissions</source>
        <translation>KeePassXC : Permissions retirées</translation>
    </message>
    <message>
        <source>KeePassXC: No entry with permissions found!</source>
        <translation>KeePassXC : Aucune entrée avec permissions trouvée !</translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <source>Application Settings</source>
        <translation>Paramètres de l&apos;application</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sécurité</translation>
    </message>
    <message>
        <source>Access error for config file %1</source>
        <translation>Erreur d&apos;accès au fichier de configuration %1</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetGeneral</name>
    <message>
        <source>Remember last databases</source>
        <translation>Se souvenir des dernières bases de données</translation>
    </message>
    <message>
        <source>Automatically save on exit</source>
        <translation>Sauvegarder automatiquement à la sortie</translation>
    </message>
    <message>
        <source>Automatically save after every change</source>
        <translation>Sauvegarder automatiquement après chaque modification</translation>
    </message>
    <message>
        <source>Minimize when copying to clipboard</source>
        <translation>Réduire lors de la copie dans le presse-papier</translation>
    </message>
    <message>
        <source>Use group icon on entry creation</source>
        <translation>Utiliser l&apos;icône de groupe à la création d&apos;une entrée</translation>
    </message>
    <message>
        <source>Global Auto-Type shortcut</source>
        <translation>Raccourci de la Saisie-Automatique</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Langue</translation>
    </message>
    <message>
        <source>Show a system tray icon</source>
        <translation>Afficher une icône dans la zone de notification</translation>
    </message>
    <message>
        <source>Hide window to system tray when minimized</source>
        <translation>Réduire la fenêtre vers la zone de notification lors de sa réduction</translation>
    </message>
    <message>
        <source>Load previous databases on startup</source>
        <translation>Charger les bases de données précédentes au démarrage</translation>
    </message>
    <message>
        <source>Automatically reload the database when modified externally</source>
        <translation>Recharger automatiquement la base de données quand celle-ci est modifiée depuis l&apos;extérieur</translation>
    </message>
    <message>
        <source>Hide window to system tray instead of app exit</source>
        <translation>Envoyer la fenêtre dans la zone de notification au lieu de quitter l&apos;application</translation>
    </message>
    <message>
        <source>Minimize window at application startup</source>
        <translation>Minimiser la fenêtre lors du démarrage de l&apos;application</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>Paramètres de base</translation>
    </message>
    <message>
        <source>Remember last key files and security dongles</source>
        <translation>Se souvenir des derniers fichiers clé et des dongles de sécurité</translation>
    </message>
    <message>
        <source>Don&apos;t mark database as modified for non-data changes (e.g., expanding groups)</source>
        <translation>Ne pas indiquer la base de données comme modifiée pour les changements hors-données (par exemple : groupes développés)</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>Saisie-Automatique</translation>
    </message>
    <message>
        <source>Use entry title and URL to match windows for global Auto-Type</source>
        <translation>Utilisez le titre de l&apos;entrée et l&apos;URL dans la correspondance des fenêtres pour la Saisie-Automatique globale.</translation>
    </message>
    <message>
        <source>Always ask before performing Auto-Type</source>
        <translation>Toujours demander avant de procéder à une Saisie-Automatique</translation>
    </message>
    <message>
        <source>Auto-Type delay</source>
        <translation>Délais de Remplissage de la Saisie-Automatique</translation>
    </message>
    <message>
        <source> ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <source>Start only a single instance of KeePassXC</source>
        <translation>Démarrer uniquement une seule instance de KeePassXC</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetSecurity</name>
    <message>
        <source>Clear clipboard after</source>
        <translation>Vider le presse-papier après</translation>
    </message>
    <message>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <source>Lock databases after inactivity of</source>
        <translation>Verrouiller les bases de données après une inactivité de</translation>
    </message>
    <message>
        <source>Show passwords in cleartext by default</source>
        <translation>Afficher les mots de passe en clair par défaut</translation>
    </message>
    <message>
        <source>Lock databases after minimizing the window</source>
        <translation>Verrouiller la base de données lorsque la fenêtre est minimisée</translation>
    </message>
    <message>
        <source>Don&apos;t require password repeat when it is visible</source>
        <translation>Ne pas demander de répéter le mot de passe lorsque celui-ci est visible</translation>
    </message>
    <message>
        <source>Timeouts</source>
        <translation>Timeouts</translation>
    </message>
    <message>
        <source>Convenience</source>
        <translation>Convenance</translation>
    </message>
    <message>
        <source>Lock databases when session is locked or lid is closed</source>
        <translation>Verrouiller les bases de données quand la session est verrouillée ou le capot fermé</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Confidentialité</translation>
    </message>
    <message>
        <source>Use Google as fallback for downloading website icons</source>
        <translation>Utilisez Google en secours pour télécharger des icônes de site web</translation>
    </message>
</context>
<context>
    <name>SetupTotpDialog</name>
    <message>
        <source>Setup TOTP</source>
        <translation>Configuration TOTP</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Clé :</translation>
    </message>
    <message>
        <source>Use custom settings</source>
        <translation>Utiliser les paramètres personnalisés</translation>
    </message>
    <message>
        <source>Note: Change these settings only if you know what you are doing.</source>
        <translation>Attention : modifiez ces paramètres seulement si vous savez ce que vous faites.</translation>
    </message>
    <message>
        <source>Time step:</source>
        <translation>Période de temps :</translation>
    </message>
    <message>
        <source>8 digits</source>
        <translation>8 chiffres</translation>
    </message>
    <message>
        <source>6 digits</source>
        <translation>6 chiffres</translation>
    </message>
    <message>
        <source>Code size:</source>
        <translation>Taille du code :</translation>
    </message>
    <message>
        <source> sec</source>
        <translation> s</translation>
    </message>
</context>
<context>
    <name>TotpDialog</name>
    <message>
        <source>Timed Password</source>
        <translation>Mot de passe programmé</translation>
    </message>
    <message>
        <source>000000</source>
        <translation>000000</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copie</translation>
    </message>
    <message>
        <source>Expires in</source>
        <translation>Expire dans</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>secondes</translation>
    </message>
</context>
<context>
    <name>UnlockDatabaseWidget</name>
    <message>
        <source>Unlock database</source>
        <translation>Déverrouiller la base de données</translation>
    </message>
</context>
<context>
    <name>WelcomeWidget</name>
    <message>
        <source>Welcome to KeePassXC</source>
        <translation>Bienvenue dans KeePassXC</translation>
    </message>
    <message>
        <source>Start storing your passwords securely in a KeePassXC database</source>
        <translation>Gardez vos mots de passe en sécurité dans une base de données KeePassXC</translation>
    </message>
    <message>
        <source>Create new database</source>
        <translation>Créer une nouvelle base de données</translation>
    </message>
    <message>
        <source>Open existing database</source>
        <translation>Ouvrir une base de données existante</translation>
    </message>
    <message>
        <source>Import from KeePass 1</source>
        <translation>Importer depuis KeePass 1</translation>
    </message>
    <message>
        <source>Import from CSV</source>
        <translation>Import depuis CSV</translation>
    </message>
    <message>
        <source>Recent databases</source>
        <translation>Bases de données récentes</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>path to a custom config file</source>
        <translation>Chemin vers un fichier de configuration personnalisé</translation>
    </message>
    <message>
        <source>key file of the database</source>
        <translation>Fichier-clé de la base de données</translation>
    </message>
    <message>
        <source>KeePassXC - cross-platform password manager</source>
        <translation>KeePassXC - Gestionnaire de mots de passe multiplateforme</translation>
    </message>
    <message>
        <source>read password of the database from stdin</source>
        <translation>Lire le mot de passe de la base de données sur l&apos;entrée standard</translation>
    </message>
    <message>
        <source>filenames of the password databases to open (*.kdbx)</source>
        <translation>noms de fichiers des bases de données de mot de passe à ouvrir (*.kdbx)</translation>
    </message>
    <message>
        <source>Copy a password to the clipboard</source>
        <translation>Copier un mot de passe dans le presse papier</translation>
    </message>
    <message>
        <source>Path of the database.</source>
        <translation>Chemin d&apos;accès de la base de données.</translation>
    </message>
    <message>
        <source>Use a GUI prompt unlocking the database.</source>
        <translation>Utiliser une invite graphique pour déverrouiller la base de données.</translation>
    </message>
    <message>
        <source>Name of the entry to clip.</source>
        <translation>Nom de l&apos;entrée épingler.</translation>
    </message>
    <message>
        <source>Extract and print the content of a database.</source>
        <translation>Extraire et imprimer le contenu d&apos;une base de données.</translation>
    </message>
    <message>
        <source>Path of the database to extract.</source>
        <translation>Chemin de la base de données à extraire.</translation>
    </message>
    <message>
        <source>Name of the command to execute.</source>
        <translation>Nom de la commande à exécuter.</translation>
    </message>
    <message>
        <source>List database entries.</source>
        <translation>Lister les entrées de la base.</translation>
    </message>
    <message>
        <source>Path of the group to list. Default is /</source>
        <translation>Chemin du groupe à lister. Par défaut : /</translation>
    </message>
    <message>
        <source>Print the UUIDs of the entries and groups.</source>
        <translation>Imprimer les UUIDs des entrées et des groupes.</translation>
    </message>
    <message>
        <source>Merge two databases.</source>
        <translation>Fusionner deux bases de données.</translation>
    </message>
    <message>
        <source>Path of the database to merge into.</source>
        <translation>Chemin de la base de données cible.</translation>
    </message>
    <message>
        <source>Path of the database to merge from.</source>
        <translation>Chemin de la base de données source.</translation>
    </message>
    <message>
        <source>Use the same password for both database files.</source>
        <translation>Utiliser le même mot de passe pour les deux bases de données. </translation>
    </message>
    <message>
        <source>Show a password.</source>
        <translation>Afficher un mot de passe.</translation>
    </message>
    <message>
        <source>Name of the entry to show.</source>
        <translation>Nom de l&apos;entrée à afficher.</translation>
    </message>
</context>
</TS>